import requests


def fetch_and_save_binary(url: str, dest: str, **kwargs) -> int:
    kwargs["stream"] = True
    resp = requests.get(url, **kwargs)
    resp.raise_for_status()

    bytes_read = 0
    with open(dest, "wb") as f:
        for chunk in resp.iter_content(chunk_size=1024):
            if chunk:
                f.write(chunk)
                bytes_read += len(chunk)

    return bytes_read



from matplotlib import pyplot as plt


def legend_to_right_of_plot(ax=None, **overrides):
    ax = ax or plt.gca()

    kwargs = dict(frameon=False, loc="center left", bbox_to_anchor=(1, 0.5))
    kwargs.update(overrides)

    ax.legend(**kwargs)
